package com.ruoyi.rocketmq.service.impl;

import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.rocketmq.domain.InitialOtherSystemMonitorData;
import com.ruoyi.rocketmq.mapper.InitialOtherSystemMonitorDataMapper;
import com.ruoyi.rocketmq.service.IInitialOtherSystemMonitorDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 系统其他信息监控数据Service业务层处理
 * 
 * @author gyt
 * @date 2025-09-23
 */
@Service
public class InitialOtherSystemMonitorDataServiceImpl implements IInitialOtherSystemMonitorDataService 
{
    @Autowired
    private InitialOtherSystemMonitorDataMapper initialOtherSystemMonitorDataMapper;

    /**
     * 查询系统其他信息监控数据
     * 
     * @param id 系统其他信息监控数据主键
     * @return 系统其他信息监控数据
     */
    @Override
    public InitialOtherSystemMonitorData selectInitialOtherSystemMonitorDataById(Long id)
    {
        return initialOtherSystemMonitorDataMapper.selectInitialOtherSystemMonitorDataById(id);
    }

    /**
     * 查询系统其他信息监控数据列表
     * 
     * @param initialOtherSystemMonitorData 系统其他信息监控数据
     * @return 系统其他信息监控数据
     */
    @Override
    public List<InitialOtherSystemMonitorData> selectInitialOtherSystemMonitorDataList(InitialOtherSystemMonitorData initialOtherSystemMonitorData)
    {
        return initialOtherSystemMonitorDataMapper.selectInitialOtherSystemMonitorDataList(initialOtherSystemMonitorData);
    }

    /**
     * 新增系统其他信息监控数据
     * 
     * @param initialOtherSystemMonitorData 系统其他信息监控数据
     * @return 结果
     */
    @Override
    public int insertInitialOtherSystemMonitorData(InitialOtherSystemMonitorData initialOtherSystemMonitorData)
    {
        return initialOtherSystemMonitorDataMapper.insertInitialOtherSystemMonitorData(initialOtherSystemMonitorData);
    }

    /**
     * 修改系统其他信息监控数据
     * 
     * @param initialOtherSystemMonitorData 系统其他信息监控数据
     * @return 结果
     */
    @Override
    public int updateInitialOtherSystemMonitorData(InitialOtherSystemMonitorData initialOtherSystemMonitorData)
    {
        initialOtherSystemMonitorData.setUpdateTime(DateUtils.getNowDate());
        return initialOtherSystemMonitorDataMapper.updateInitialOtherSystemMonitorData(initialOtherSystemMonitorData);
    }

    /**
     * 批量删除系统其他信息监控数据
     * 
     * @param ids 需要删除的系统其他信息监控数据主键
     * @return 结果
     */
    @Override
    public int deleteInitialOtherSystemMonitorDataByIds(Long[] ids)
    {
        return initialOtherSystemMonitorDataMapper.deleteInitialOtherSystemMonitorDataByIds(ids);
    }

    /**
     * 删除系统其他信息监控数据信息
     * 
     * @param id 系统其他信息监控数据主键
     * @return 结果
     */
    @Override
    public int deleteInitialOtherSystemMonitorDataById(Long id)
    {
        return initialOtherSystemMonitorDataMapper.deleteInitialOtherSystemMonitorDataById(id);
    }
}
